@@ -43,7 +43,7 @@ void GtkDialogs::ui_warning(App& app, const Glib::ustring& text, const Glib::ust
   dialog.run();
 }
 
-Glib::ustring GtkDialogs::ui_file_select_open(App& app)
+Glib::ustring GtkDialogs::ui_file_select_open(App& app, const Glib::ustring& starting_folder_uri)
 {
   Gtk::FileChooserDialog fileChooser_Open(gettext("Open Document"), Gtk::FILE_CHOOSER_ACTION_OPEN);
 
@@ -56,6 +56,9 @@ Glib::ustring GtkDialogs::ui_file_select_open(App& app)
 
   fileChooser_Open.set_default_response(Gtk::RESPONSE_OK);
 
+  if(!starting_folder_uri.empty())
+    fileChooser_Open.set_current_folder_uri(starting_folder_uri);
+
   int response_id = fileChooser_Open.run();
   fileChooser_Open.hide();
   if(response_id != Gtk::RESPONSE_CANCEL)
@@ -78,7 +81,7 @@ Glib::ustring GtkDialogs::ui_file_select_save(App& app, const Glib::ustring& old
   fileChooser_Save.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
 
   fileChooser_Save.set_default_response(Gtk::RESPONSE_OK);
-   
+
   //Make the save dialog show the existing filename, if any:
   if(!old_filepath.empty())
     fileChooser_Save.set_filename(old_filepath);
