@@ -29,12 +29,12 @@ namespace Bakery
 class GtkDialogs
 {
 public:
-  static void ui_warning(const Glib::ustring& text);
-  static Glib::ustring ui_file_select_open();
-  static Glib::ustring ui_file_select_save(const Glib::ustring& old_filepath);
+  static void ui_warning(App& app, const Glib::ustring& text, const Glib::ustring& secondary_text);
+  static Glib::ustring ui_file_select_open(App& app, const Glib::ustring& starting_folder_uri = Glib::ustring());
+  static Glib::ustring ui_file_select_save(App& app, const Glib::ustring& old_filepath);
   static void ui_show_modification_status();
-  static App_WithDoc::enumSaveChanges ui_offer_to_save_changes(const std::string& filepath);
-  static bool ui_ask_overwrite(const std::string& filepath);
+  static App_WithDoc::enumSaveChanges ui_offer_to_save_changes(App& app, const std::string& filepath);
+  static bool ui_ask_overwrite(App& app, const std::string& filepath);
 };
 
 } //namespace
